@@ -1,7 +1,8 @@
 test_that("works by default", {
   pkg <- structure(
     list(
-      desc = desc::desc(text = "Authors@R: person('First', 'Last', role = 'cre')")
+      desc = desc::desc(text = "Authors@R: person('First', 'Last', role = 'cre')"),
+      src_path = tempdir()
     ),
     class = "pkgdown"
   )
@@ -16,6 +17,7 @@ test_that("includes package component", {
     list(
       package = "noodlr",
       desc = desc::desc(text = "Authors@R: person('First', 'Last', role = 'cre')"),
+      src_path = tempdir(),
       meta = list(
         footer = list(
           structure = list(left = "package")
@@ -30,6 +32,7 @@ test_that("includes package component", {
 test_that("can use custom components", {
   pkg <- structure(list(
     desc = desc::desc(text = "Authors@R: person('a', 'b', roles = 'cre')"),
+    src_path = tempdir(),
     meta = list(
       footer = list(
         structure = list(left = "test"),
@@ -44,6 +47,7 @@ test_that("can use custom components", {
 test_that("multiple components are pasted together", {
   pkg <- structure(list(
     desc = desc::desc(text = "Authors@R: person('a', 'b', roles = 'cre')"),
+    src_path = tempdir(),
     meta = list(
       footer = list(
         structure = list(left = c("a", "b")),
@@ -55,3 +59,17 @@ test_that("multiple components are pasted together", {
   expect_equal(data_footer(pkg)$left, "<p>a b</p>")
 })
 
+test_that("validates meta components", {
+  data_footer_ <- function(...) {
+    pkg <- local_pkgdown_site(meta = list(...))
+    data_footer(pkg)
+  }
+
+  expect_snapshot(error = TRUE, {
+    data_footer_(footer = 1)
+    data_footer_(footer = list(structure = 1))
+    data_footer_(footer = list(components = 1))
+    data_footer_(authors = list(footer = list(roles = 1)))
+    data_footer_(authors = list(footer = list(text = 1)))
+  })
+})
\ No newline at end of file
